==> apache-iotdb-1.2.2-source-release.zip: apache-iotdb-1.2.2/iotdb-core/datanode/src/main/java/org/apache/iotdb/db/queryengine/common/schematree/visitor/SchemaTreeVisitorFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.db.queryengine.common.schematree.visitor;

import org.apache.iotdb.commons.path.MeasurementPath;
import org.apache.iotdb.commons.path.PartialPath;
import org.apache.iotdb.db.queryengine.common.schematree.node.SchemaNode;

public class SchemaTreeVisitorFactory {

  private SchemaTreeVisitorFactory() {
    // forbidden instantiation
  }

  public static SchemaTreeDeviceVisitor createSchemaTreeDeviceVisitor(
      SchemaNode root, PartialPath pathPattern, boolean isPrefixMatch) {
    return new SchemaTreeDeviceVisitor(root, pathPattern, isPrefixMatch);
  }

  public static SchemaTreeMeasurementVisitor createSchemaTreeMeasurementVisitor(
      SchemaNode root, PartialPath pathPattern, boolean isPrefixMatch) {
    return new SchemaTreeMeasurementVisitor(root, pathPattern, isPrefixMatch);
  }

  public static SchemaTreeVisitorWithLimitOffsetWrapper<MeasurementPath>
      createSchemaTreeMeasurementVisitor(
          SchemaNode root,
          PartialPath pathPattern,
          boolean isPrefixMatch,
          int slimit,
          int soffset) {
    return new SchemaTreeVisitorWithLimitOffsetWrapper<>(
        new SchemaTreeMeasurementVisitor(root, pathPattern, isPrefixMatch), slimit, soffset);
  }
}

==> apache-iotdb-1.3.0-source-release.zip: apache-iotdb-1.3.0/iotdb-core/datanode/src/main/java/org/apache/iotdb/db/queryengine/common/schematree/visitor/SchemaTreeVisitorFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.db.queryengine.common.schematree.visitor;

import org.apache.iotdb.commons.path.MeasurementPath;
import org.apache.iotdb.commons.path.PartialPath;
import org.apache.iotdb.commons.path.PathPatternTree;
import org.apache.iotdb.db.queryengine.common.schematree.node.SchemaNode;

public class SchemaTreeVisitorFactory {

  private SchemaTreeVisitorFactory() {
    // forbidden instantiation
  }

  public static SchemaTreeDeviceVisitor createSchemaTreeDeviceVisitor(
      SchemaNode root, PartialPath pathPattern, boolean isPrefixMatch) {
    return new SchemaTreeDeviceVisitor(root, pathPattern, isPrefixMatch);
  }

  public static SchemaTreeMeasurementVisitor createSchemaTreeMeasurementVisitor(
      SchemaNode root, PartialPath pathPattern, boolean isPrefixMatch) {
    return new SchemaTreeMeasurementVisitor(root, pathPattern, isPrefixMatch);
  }

  public static SchemaTreeVisitorWithLimitOffsetWrapper<MeasurementPath>
      createSchemaTreeMeasurementVisitor(
          SchemaNode root,
          PartialPath pathPattern,
          boolean isPrefixMatch,
          int slimit,
          int soffset) {
    return new SchemaTreeVisitorWithLimitOffsetWrapper<>(
        new SchemaTreeMeasurementVisitor(root, pathPattern, isPrefixMatch), slimit, soffset);
  }

  public static SchemaTreeDeviceVisitor createSchemaTreeDeviceVisitor(
      SchemaNode root, PartialPath pathPattern, boolean isPrefixMatch, PathPatternTree scope) {
    return new SchemaTreeDeviceVisitor(root, pathPattern, isPrefixMatch, scope);
  }

  public static SchemaTreeMeasurementVisitor createSchemaTreeMeasurementVisitor(
      SchemaNode root, PartialPath pathPattern, boolean isPrefixMatch, PathPatternTree scope) {
    return new SchemaTreeMeasurementVisitor(root, pathPattern, isPrefixMatch, scope);
  }

  public static SchemaTreeVisitorWithLimitOffsetWrapper<MeasurementPath>
      createSchemaTreeMeasurementVisitor(
          SchemaNode root,
          PartialPath pathPattern,
          boolean isPrefixMatch,
          int slimit,
          int soffset,
          PathPatternTree scope) {
    return new SchemaTreeVisitorWithLimitOffsetWrapper<>(
        new SchemaTreeMeasurementVisitor(root, pathPattern, isPrefixMatch, scope), slimit, soffset);
  }
}
